# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from notifications_server_connector.models.notification_author_response import NotificationAuthorResponse  # noqa: E501

class TestNotificationAuthorResponse(unittest.TestCase):
    """NotificationAuthorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NotificationAuthorResponse:
        """Test NotificationAuthorResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NotificationAuthorResponse`
        """
        model = NotificationAuthorResponse()  # noqa: E501
        if include_optional:
            return NotificationAuthorResponse(
                id = 56,
                email = '',
                role_id = 56,
                first_name = '',
                last_name = '',
                nickname = '',
                avatar_id = ''
            )
        else:
            return NotificationAuthorResponse(
                id = 56,
                email = '',
                role_id = 56,
        )
        """

    def testNotificationAuthorResponse(self):
        """Test NotificationAuthorResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
